========================
 Invenio-Base v1.0.0a12
========================

Invenio-Base v1.0.0a12 was released on June 29, 2016.

About
-----

Base package for building the Invenio application.

*This is an experimental developer preview release.*

What's new
----------

- Initial refactoring for Invenio 3 compatible packages.

Installation
------------

   $ pip install invenio-base==1.0.0a12

Documentation
-------------

   http://pythonhosted.org/invenio-base/

Happy hacking and thanks for flying Invenio-Base.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-base
|   URL: http://inveniosoftware.org
